@@ -1,7 +1,7 @@
 # Starfish - Perl-based System for Text-Embedded
 #     Programming and Preprocessing
 #
-# (c) 2001-2015 Vlado Keselj http://web.cs.dal.ca/~vlado
+# (c) 2001-2016 Vlado Keselj http://web.cs.dal.ca/~vlado vlado@dnlp.ca
 #               and contributing authors
 #
 # See the documentation following the code.  You can also use the
@@ -29,7 +29,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS); # Exporter vars
 use vars qw($NAME $ABSTRACT $VERSION);
 $NAME     = 'Starfish';
 $ABSTRACT = 'Perl-based System for Text-Embedded Programming and Preprocessing';
-$VERSION  = '1.18';
+$VERSION  = '1.19';
 
 use vars qw($Revision);
 ($Revision = substr(q$Revision: 392 $, 10)) =~ s/\s+$//;
@@ -428,8 +428,10 @@ sub evaluate_py {
 	my $indent = '';
 	if ($pref =~ /^(\s+)#/) { $indent = $1 }
 	elsif ($c =~ /^(\s+)#/m) { $indent = $1 }
-	$suf .= $indent."#+\n".$::O.
-	        "\n".$indent."#-\n";
+	$suf .= $indent."#+\n".$::O;
+	       # Avoiding extra \n before #-
+	$suf .= "\n" unless rindex($suf, "\n")==length($suf)-1;
+	$suf .= $indent."#-\n";
     }
     return "$pref$c$suf";
 }
@@ -456,8 +458,10 @@ sub evaluate_py1 {
  
     if ($self->{REPLACE}) { return $indent.$::O }
     elsif ($::O eq '') { return "$indent#$prefix$c!>\n" }
-    else
-    { return "$indent#$prefix$c!>\n$indent#+\n".$::O."\n$indent#-\n" }
+    else {
+      $::O =~ s/^/$indent/gmx;
+      my $r= "$indent#$prefix$c!>\n$indent#+\n".$::O;
+      $r =~ s/\n?$/\n/; $r.="$indent#-\n"; } # no extra \n
 }
 
 # predefined evaluator: echo
@@ -1434,7 +1438,7 @@ Old macro definition can be overriden by:
 
 =head2 $O
 
-After executing a snippet, the contetns of this variable represent the
+After executing a snippet, the contents of this variable represent the
 snippet output.
 
 =head2 $Star
@@ -1744,7 +1748,7 @@ appends list elements to the file.
 
 =head2 echo I<string>
 
-appends string to the special variable $).
+appends string to the special variable $0.
 
 =head2 DATE AND TIME FUNCTIONS
 
@@ -1892,7 +1896,7 @@ other comments.
 
 =head1 AUTHORS
 
- 2001-2013 Vlado Keselj http://web.cs.dal.ca/~vlado
+ 2001-2015 Vlado Keselj http://web.cs.dal.ca/~vlado
            and contributing authors:
       2007 Charles Ikeson (overhaul of test.pl)
 
@@ -1959,4 +1963,4 @@ interface.
 =back
 
 =cut
-# $Id: Starfish.pm 392 2012-11-12 23:50:45Z vlado $
+# $Id: Starfish.pm 243 2016-05-11 09:59:42Z vlado $
