@@ -139,9 +139,10 @@ chdir 'tmp' or die;
     &testcase(22);    
 
     # 24
-    copy('../testfiles/24.py','24.py');
-    `$^X -I. -- starfish 24.py`;
-    okfiles('../testfiles/24.py.out', '24.py');
+    &testcase(24);
+    #copy('../testfiles/24.py','24.py');
+    #`$^X -I. -- starfish 24.py`;
+    #okfiles('../testfiles/24.py.out', '24.py');
 
     # 26
     copy('../testfiles/26_include_example.html','26_include_example.html');
@@ -173,41 +174,46 @@ sub getfile($) {
 sub testcase {
     my $testnum = shift;
     my ($infile, $procfile, $replace, $out, $outfile);
+    my $testdir = "test-$testnum";
+    if (-d $testdir) { `rm -rfv $testdir` }
+    mkdir $testdir, 0700 or die "can't mkdir $testdir: $!";
+    chdir $testdir or die;
+    my $testfilesdir = '../../testfiles';
 
-    if ( -e "../testfiles/$testnum.in" and $#_==-1) {
+    if ( -e "$testfilesdir/$testnum.in" and $#_==-1) {
 	$infile   = "$testnum.in";
 	$procfile = "$testnum.in";
 	$outfile  = "$testnum.out";
     }
-    elsif ( -e "../testfiles/$testnum.in" and
+    elsif ( -e "$testfilesdir/$testnum.in" and
 	    $#_==0 and $_[0] eq 'out' ) {
 	$infile   = "$testnum.in";
 	$procfile = "$testnum.in";
 	$outfile  = "$testnum.out";
 	$out      = "$testnum.out";
     }
-    elsif ( -e "../testfiles/$testnum.in" and
+    elsif ( -e "$testfilesdir/$testnum.in" and
 	    $#_==0 and $_[0] eq 'replace' ) {
 	$infile   = "$testnum.in";
 	$procfile = "$testnum.in";
 	$outfile  = "$testnum.out";
 	$replace  = "$testnum.out";
     }
-    elsif ( -e "../testfiles/${testnum}_html.in" ) {
+    elsif ( -e "$testfilesdir/${testnum}_html.in" ) {
 	$infile = "${testnum}_html.in";
 	$procfile = "$testnum.html";
 	$outfile = "${testnum}_html.out";
         if ($#_ > -1 and $_[0] eq 'replace')
 	{  $replace = "${testnum}_out.html" }
     }
-    elsif ( -e "../testfiles/${testnum}_Makefile.in" ) {
+    elsif ( -e "$testfilesdir/${testnum}_Makefile.in" ) {
 	$infile = "${testnum}_Makefile.in";
 	$procfile = "Makefile";
 	$outfile = "${testnum}_Makefile.out";
         if ($#_ > -1 and $_[0] eq 'replace')
 	{  $replace = "${testnum}_Makefile.out" }
     }
-    elsif ( -e "../testfiles/${testnum}_tex.in" ) {
+    elsif ( -e "$testfilesdir/${testnum}_tex.in" ) {
 	my $ext = $1;
 	$infile = "${testnum}_tex.in";
 	$procfile = "$testnum.tex";
@@ -215,38 +221,45 @@ sub testcase {
         if ($#_ > -1 and $_[0] eq 'replace')
 	{  $replace = "${testnum}_out.tex" }
     }
-    elsif ( -e "../testfiles/${testnum}.html.sfish" ) {
+    elsif ( -e "$testfilesdir/${testnum}.html.sfish" ) {
 	$infile = "${testnum}.html.sfish";
 	$procfile = "$testnum.html.sfish";
 	$replace = "$testnum.html";
 	$outfile = "${testnum}_html.out";
     }
-    elsif ( -e "../testfiles/${testnum}_java.in" and
+    elsif ( -e "$testfilesdir/${testnum}_java.in" and
 	    $#_==0 and $_[0] eq 'out' ) {
 	$infile = "${testnum}_java.in";
 	$procfile = "$testnum.java";
 	$outfile = "${testnum}_java.out";
 	$out     = "${testnum}_java.out";
     }
+    elsif ( -e "$testfilesdir/${testnum}.py" and
+	    -e "$testfilesdir/${testnum}.py.out" ) {
+	$infile = "${testnum}.py";
+	$procfile = "$testnum.py";
+	$outfile = "${testnum}.py.out";
+    }
     else { die }
 
-    copy("../testfiles/$infile", "$procfile");
+    copy("$testfilesdir/$infile", "$procfile");
     if ($replace) {
 	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -replace -o=$replace $procfile`;
 	starfish_cmd('-e=$ver="testver"', '-replace', "-o=$replace", $procfile);
-	#okfiles("../testfiles/$outfile", $replace);
-	comparefiles("../testfiles/$outfile", $replace);
+	#okfiles("$testfilesdir/$outfile", $replace);
+	comparefiles("$testfilesdir/$outfile", $replace);
     }
     elsif ($out) {
 	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" -o=$out $procfile`;
 	starfish_cmd('-e=$ver="testver"', "-o=$out", $procfile);
-	okfiles("../testfiles/$outfile", $out);
+	okfiles("$testfilesdir/$outfile", $out);
     }
     else {
 	#`perl -I. -- starfish -e="$slash_hack\$ver=\"testver\"" $procfile`;
 	starfish_cmd('-e=$ver="testver"', $procfile);
-	okfiles("../testfiles/$outfile", $procfile);
+	okfiles("$testfilesdir/$outfile", $procfile);
     }
+    chdir '..' or die;
 }
 
 sub comparefiles {
